==> com.liferay.commerce.pricing.web-3.0.35-sources.jar: com/liferay/commerce/pricing/web/internal/servlet/taglib/ui/constants/CommercePriceListScreenNavigationConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.pricing.web.internal.servlet.taglib.ui.constants;

/**
 * @author Alessio Antonio Rendina
 */
public class CommercePriceListScreenNavigationConstants {

	public static final String CATEGORY_KEY_CATEGORIES = "categories";

	public static final String CATEGORY_KEY_DETAILS = "details";

	public static final String CATEGORY_KEY_ENTRIES = "entries";

	public static final String CATEGORY_KEY_INFO = "info";

	public static final String CATEGORY_KEY_PRICE_MODIFIERS = "price-modifiers";

	public static final String CATEGORY_KEY_PRICING_CLASSES = "product-groups";

	public static final String CATEGORY_KEY_PRODUCTS = "products";

	public static final String CATEGORY_KEY_QUALIFIERS = "qualifiers";

	public static final String
		SCREEN_NAVIGATION_KEY_COMMERCE_PRICE_LIST_GENERAL =
			"commerce.price.list.general.v2";

	public static final String
		SCREEN_NAVIGATION_KEY_COMMERCE_PRICE_MODIFIER_GENERAL =
			"commerce.price.modifier.general";

}

==> com.liferay.commerce.pricing.web-4.0.42-sources.jar: com/liferay/commerce/pricing/web/internal/servlet/taglib/ui/constants/CommercePriceListScreenNavigationConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.pricing.web.internal.servlet.taglib.ui.constants;

/**
 * @author Alessio Antonio Rendina
 */
public class CommercePriceListScreenNavigationConstants {

	public static final String CATEGORY_KEY_CATEGORIES = "categories";

	public static final String CATEGORY_KEY_DETAILS = "details";

	public static final String CATEGORY_KEY_ENTRIES = "entries";

	public static final String CATEGORY_KEY_INFO = "info";

	public static final String CATEGORY_KEY_PRICE_MODIFIERS = "price-modifiers";

	public static final String CATEGORY_KEY_PRICING_CLASSES = "product-groups";

	public static final String CATEGORY_KEY_PRODUCTS = "products";

	public static final String CATEGORY_KEY_QUALIFIERS = "qualifiers";

	public static final String
		SCREEN_NAVIGATION_KEY_COMMERCE_INSTANCE_PRICE_ENTRY_GENERAL =
			"commerce.product.instance.price.entry.general";

	public static final String
		SCREEN_NAVIGATION_KEY_COMMERCE_PRICE_LIST_GENERAL =
			"commerce.price.list.general.v2";

	public static final String
		SCREEN_NAVIGATION_KEY_COMMERCE_PRICE_MODIFIER_GENERAL =
			"commerce.price.modifier.general";

}
